******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Prep controls used in multiple analyses

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
* GDP  

import excel "./Data/Controls/BEA_GDPbyState_clear.xls", sheet("Sheet0") firstrow clear
* rename from label 
foreach v of varlist C-W {
   local x : variable label `v'
   rename `v' gdp`x'
}
* reshape 
reshape long gdp, i(GeoFips GeoName) j(year)

* rename for consistency 
rename GeoFips area_fips

tempfile gdp
save `gdp'

******************************************************************************************************************************************************************************
* Unemployment 

import excel "./Data/Controls/UnemploymentState_cleanforimport.xlsx", sheet("Sheet1") firstrow clear
keep statefips year unemployment_peroflabor
keep if strlen(statefips) == 2
destring year, replace 
rename statefips area_fips 
replace area_fips = area_fips + "000"
rename unemployment_peroflabor unemp

******************************************************************************************************************************************************************************
* Merge macro files and generate lags 

* merge the two 
merge 1:1 area_fips year using `gdp'
keep if _merge == 3
drop _merge 
tab year

* introduce lag
replace year = year + 1
tab year 
rename gdp L1_gdp 
rename unemp L1_unemp 

* save tempfile
tempfile macrocontrols
save `macrocontrols'

******************************************************************************************************************************************************************************
* Migration controls (raw data obtained via IPUMS ACS)

use "./Data/Controls/Data_ExtendedControls/usa_00015.dta", clear /*downloaded IPUMS file*/

* housekeeping for var names
tostring statefip, gen(area_fips)
replace area_fips = "0" + area_fips if strlen(area_fips) == 1
replace area_fips = area_fips + "000"

* gen variables of interest 
gen betweenstatemigration = (migrate1 == 3)
gen abroadmigration = (migrate1 == 4)

* collapse to panel structure 
collapse abroadmigration betweenstatemigration, by(area_fips year)

* gen lags
replace year = year + 1
rename abroadmigration L1_abroadmigration 
rename betweenstatemigration L1_betweenstatemigration

******************************************************************************************************************************************************************************
* Merge control files and save 

* merge migration and macro 
merge 1:1 area_fips year using `macrocontrols'
keep if _merge == 3
drop _merge 

* save new control file 
save "./Data/Controls/extendedstatecontrols.dta", replace







