******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* QCEW state-level prep and analyses

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Read raw data and prep file

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Import QCEW data


filelist, dir("./Data/Census/Data_QCEW/QCEW_RAWData/") pat("*.csv") save("./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta") replace
use "./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta", clear 
local obs = _N
forvalues i=1/`obs' {
	use "./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta" in `i', clear
	local d = dirname + "/" + filename
	local f = filename /*needed for getting the years*/ 
	import delimited using "`d'", stringcols(_all) clear 
	gen filename = "`f'"
	keep if agglvl_code == "58" /*keep only State-level 6 digits*/
	keep if own_code == "5" /*keep only privately owned*/
	keep if industry_code == "541211" | industry_code == "541110" /*keep only CPAs and lawyers*/
	foreach var of varlist *disclosure_code {
		gen `var'_str = "null" 
		if missing(`var') {
			replace `var'_str = "blank"
		}
		else {
			replace `var'_str = "N"
		}
		drop `var'
	}
	tempfile save`i'
	save "`save`i''"
}

use "`save1'", clear
forvalues i=2/`obs' {
	append using "`save`i''"
}


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Clean file / var formats

******************************************************************************************************************************************************************************
* Var format
ds area_fips industry_code qtr filename disclosure_code_str lq_disclosure_code_str oty_disclosure_code_str, not
foreach v of var `r(varlist)' {
	destring `v', replace 
}

******************************************************************************************************************************************************************************
* Clean up state variable

* interim step to get the state name: merge with a name cross walk file 
merge m:1 area_fips using "./Data/Census/Data_QCEW/FIPSandNamesCrosswalk.dta" 
assert _merge != 1
keep if _merge == 3
drop _merge

* area_title
split area_title, p(" -- ")
replace area_title = area_title1
drop area_title1 area_title2


******************************************************************************************************************************************************************************
* Sample screen

* toss out excluded sates
gen excludestate = (area_title == "Virginia" | area_title == "Ohio" | area_title == "Virgin Islands" | area_title == "Puerto Rico" | area_title == "Hawaii")
drop if excludestate == 1

* sample period alignment
keep if year >= 2003

******************************************************************************************************************************************************************************
* Merge in controls

merge m:1 area_fips year using "./Data/Controls/extendedstatecontrols.dta" 
keep if _merge == 3
drop _merge 

******************************************************************************************************************************************************************************
* Analyses prep

* gen shorter var names for handling
gen pay = avg_annual_pay
gen emp = annual_avg_emplvl

* gen main responses
gen logpay = log(pay) 
gen logemp = log(emp)

* gen weights -- empshares
egen occ_year_id = group(industry_code year)
preserve 
collapse (sum) emp, by(occ_year_id)
rename emp emptotal
tempfile emptotal
save `emptotal'
restore 
merge m:1 occ_year_id using `emptotal'
assert _merge == 3 
drop _merge
gen empshare = emp / emptotal

* gen x-section treatment dummies for DiDiD and sample inclusion
capture gen cpa = (industry_code == "541211")
capture gen lawyer = (industry_code == "541110")
capture gen cpalawyer = (cpa == 1 | lawyer == 1)

* merge in treatment dummies
capture drop L1_CPAMobility_Effec_longpanel
preserve
use "./Data/Helper/LawDummiesCensusState.dta", clear
keep area_fips year adoption_year L1_CPAMobility_Effec_longpanel
tempfile mobilitydummies
save `mobilitydummies'
restore 
capture drop _merge 
merge m:1 area_fips year using `mobilitydummies'
drop if _merge == 2
drop _merge 

* shorten name for handling in DiDiD
rename L1_CPAMobility_Effec_longpanel L1_CPAMob
replace L1_CPAMob = 1 if year > 2015 /*all sample states adopted then*/

* gen DiDiD treatment dummies
gen L1_CPAMob_cpa = L1_CPAMob * cpa 

* gen event time dummies for graph analysis
gen effectiveyear = adoption_year
do "./Dofiles/reltimedummmies.do" /*outsourced event-time dummy generator for brevity*/

* gen FEs 
egen cpa_year = group(cpa year)
egen state_year = group(area_fips year)
egen state_occ_id = group(industry_code area_fips)
egen state_id = group(area_fips)

* gen logestab 
gen logestab = log(annual_avg_estabs)

* gen empl2estab
gen empl2estab = annual_avg_emplvl / annual_avg_estabs
gen logempl2estab = log(empl2estab)

* gen estabshares 
bysort occ_year_id: egen estabtotal = total(annual_avg_estabs)
gen estabshare = annual_avg_estabs / estabtotal


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Analyses: QCEW state-Level

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Figure 1

******************************************************************************************************************************************************************************
* Figure 1, Panel A: Timing reg CPA only 

capture gen zero = 0 
label variable zero "t-1" 
reghdfe logpay reltimeleadlarger3_cpa reltimelead3_cpa reltimelead2_cpa zero /*reltimelead1_cpa */  reltime0_cpa reltimelag1_cpa ///
	reltimelag2_cpa reltimelag3_cpa reltimelaglarger3_cpa ///
	L1_unemp L1_gdp L1_abroadmigration L1_betweenstatemigration if cpa == 1 [aw = empshare], a(state_id year) cluster(state_id)
coefplot, keep(reltime* zero) omitted vertical ///
	yscale(r(-0.1 0.1)) ylabel(-0.1(.05)0.1) ci(95) ciopt(recast(rcap) lcolor(gs0)) mcolor(gs0) lcolor(gs0) mcolor(gs0) xline(4.5, lpattern(dash) lcolor(gs0)) graphregion(color(white)) 
graph export "./Output/Figure1_PanelA.pdf", as(pdf) replace
graph close

******************************************************************************************************************************************************************************
* Figure 1, Panel C: Timing reg CPA vs lawyers

capture gen zero = 0 
label variable zero "t-1" 
reghdfe logpay reltimeleadlarger3_cpa reltimelead3_cpa reltimelead2_cpa zero /* reltimelead1_cpa */ reltime0_cpa reltimelag1_cpa ///
	reltimelag2_cpa reltimelag3_cpa reltimelaglarger3_cpa if cpalawyer == 1 [aw = empshare], a(cpa_year state_year state_occ_id) cluster(state_id)
coefplot, keep(reltime* zero) omitted vertical ///
	yscale(r(-0.1 0.1)) ylabel(-0.1(.05)0.1) ci(95) ciopt(recast(rcap) lcolor(gs0)) mcolor(gs0) lcolor(gs0) mcolor(gs0) xline(4.5, lpattern(dash) lcolor(gs0)) graphregion(color(white)) 
graph export "./Output/Figure1_PanelC.pdf", as(pdf) replace
graph close
	
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Table 2

******************************************************************************************************************************************************************************
* Table 2, Panel A: Descriptives

* CPA only
tabstat pay logpay emp logemp L1_unemp L1_gdp L1_betweenstatemigration L1_abroadmigration if cpa == 1 ///
	, s(n mean sd p1 p25 p50 p75 p99) columns(statistics) 

******************************************************************************************************************************************************************************
* Table 2, Panel B: Baseline wage

eststo clear 
eststo: reghdfe logpay L1_CPAMob if cpa == 1 [aw = empshare], a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logpay L1_CPAMob L1_unemp if cpa == 1 [aw = empshare], a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logpay L1_CPAMob L1_gdp if cpa == 1 [aw = empshare], a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logpay L1_CPAMob L1_betweenstatemigration if cpa == 1 [aw = empshare], a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logpay L1_CPAMob L1_abroadmigration if cpa == 1 [aw = empshare], a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logpay L1_CPAMob L1_unemp L1_gdp L1_betweenstatemigration L1_abroadmigration if cpa == 1 [aw = empshare], a(state_occ_id cpa_year) cluster(state_id)
esttab using "./Output/Table2_PanelB.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

******************************************************************************************************************************************************************************
* Table 2, Panel C: Employment

eststo clear
eststo: reghdfe logemp L1_CPAMob if cpa == 1, a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logemp L1_CPAMob L1_unemp if cpa == 1, a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logemp L1_CPAMob L1_gdp if cpa == 1, a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logemp L1_CPAMob L1_betweenstatemigration if cpa == 1, a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logemp L1_CPAMob L1_abroadmigration if cpa == 1, a(state_occ_id cpa_year) cluster(state_id)
eststo: reghdfe logemp L1_CPAMob L1_unemp L1_gdp L1_betweenstatemigration L1_abroadmigration if cpa == 1, a(state_occ_id cpa_year) cluster(state_id)
esttab using "./Output/Table2_PanelC.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Table 3, Panel B: Triple Diff CPA vs lawyers

eststo clear 
eststo: reghdfe logpay L1_CPAMob_cpa if cpalawyer == 1 [aw = empshare], a(cpa_year state_year state_occ_id) cluster(state_id)
eststo: reghdfe logemp L1_CPAMob_cpa if cpalawyer == 1, a(cpa_year state_year state_occ_id) cluster(state_id)
eststo: reghdfe logempl2estab L1_CPAMob_cpa if cpalawyer == 1 [aw = estabshare], a(cpa_year state_year state_occ_id) cluster(state_id)
eststo: reghdfe logestab L1_CPAMob_cpa if cpalawyer == 1, a(cpa_year state_year state_occ_id) cluster(state_id)
esttab using "./Output/Table3_PanelB.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

