******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* SUSB State-level prep and analyses 

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Read in and clean data

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Raw data processing 

filelist, dir("./Data/Census/Data_SUSB/SUSB_6digitnaics/") pat("*.txt") save("./Data/Census/Data_SUSB/SUSB_6digitnaics/SUSB_datasets.dta") replace

use "./Data/Census/Data_SUSB/SUSB_6digitnaics/SUSB_datasets.dta", clear 
local obs = _N
forvalues i=1/`obs' {
	use "./Data/Census/Data_SUSB/SUSB_6digitnaics/SUSB_datasets.dta" in `i', clear
	local f = dirname + "/" + filename
	local g = filename
	import delimited "`f'", encoding(ISO-8859-1) clear
	keep if naics == "541211" | naics == "541110" /*keep CPAs and Lawyers for triple and quadruple diff*/
	gen source = "`f'"
	tempfile save`i'
	save "`save`i''"
}

*append all files
use "`save1'", clear
	forvalues i=2/`obs' {
    append using "`save`i''"
}


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Clean up file 

* keep only state-level variables
drop if state == 0 /*drop national-level variables */

* gen year variable 
capture drop year
gen year = substr(source, -8, 4)
destring year, replace

* sort data
sort state statedscr entrsize year

* gen area fips / statename for merges
gen area_fips = state
tostring area_fips, replace 
replace area_fips = "0" + area_fips if strlen(area_fips) == 1
replace area_fips = area_fips + "000"
gen statename = statedscr

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Variable consistency checks and adjustments

* sort out differences in variable names (not definitions) across SUSB year files variable by variable: 

******************************************************************************************************************************************************************************
* Employment

tab year if missing(empl) /*this is as of 2011*/
tab year if missing(empl_n) /*this is before 2011*/
gen empltemp = .
replace empltemp = empl if year < 2011
replace empltemp = empl_n if year >= 2011
tab year if missing(empltemp) /* none missing*/
drop empl empl_n
rename empltemp empl

******************************************************************************************************************************************************************************
* Payroll

tab year if missing(payr) /*as of 2011 missing*/
tab year if missing(payr_n) /*up until 2010*/
gen paytemp = .
replace paytemp = payr if year < 2011
replace paytemp = payr_n if year >= 2011
tab year if missing(paytemp) /*done - none missing*/
drop payr payr_n
rename paytemp payr 


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Analysis prep

******************************************************************************************************************************************************************************
* Merge in treatment dummies

preserve
use "./Data/Helper/LawDummiesCensusState.dta", clear
keep area_fips year adoption_year L1_CPAMobility_Effec_longpanel
tempfile mobilitydummies
save `mobilitydummies'

restore 
* merge m:1 (multiple size classes per area_fips and year)
merge m:1 area_fips year using `mobilitydummies'
keep if _merge == 3 
drop _merge 

******************************************************************************************************************************************************************************
*  Gen outcome variables 

gen pay = payr / empl 
gen logpay = log(pay)
gen logempl = log(empl)
gen logestb = log(estb)
gen emp2estb = empl / estb
gen logemp2estb = log(emp2estb)

tab year if missing(logpay)
tab entrsize year if missing(logpay)  /*Tests are conducted on Class 5 (<20) and Class 6 (20-99) to max coverage -- next step*/

******************************************************************************************************************************************************************************
* Gen and keep size buckets 

gen smallfirm = (entrsize == 5) /*<20 employees*/
gen largefirm = (entrsize == 6) /*20-99 employees*/
gen inclfirm = (entrsize == 5 | entrsize == 6)
keep if inclfirm == 1

******************************************************************************************************************************************************************************
* Gen industry FE for DiDiD and DiDiDiD

gen cpa = (naics == "541211")
gen lawyer = (naics == "541110")

******************************************************************************************************************************************************************************
* Gen FEs 

capture drop *_id
egen state_id = group(area_fips)
egen state_naics_id = group(area_fips naics)
egen state_size_id = group(area_fips entrsize)
egen state_naics_size_id = group(area_fips naics entrsize)
egen year_id = group(year)
egen state_year_id = group(area_fips year)
egen naics_year_id = group(naics year)
egen size_year_id = group(entrsize year)
egen naics_size_year_id = group(naics entrsize year)
egen state_naics_year_id = group(area_fips naics year)  
egen state_size_year_id = group(area_fips entrsize year)

******************************************************************************************************************************************************************************
* Gen treatments 

* Shorten var name for DiDiD and DiDiDiD treatment dummy construction
rename L1_CPAMobility_Effec_longpanel L1_CPAMob 

capture gen L1_CPAMob_small = L1_CPAMob * smallfirm * cpa
capture gen L1_CPAMob_small_cpa = L1_CPAMob * smallfirm * cpa

capture gen L1_CPAMob_large = L1_CPAMob * largegfirm * cpa
capture gen L1_CPAMob_large_cpa = L1_CPAMob * largefirm * cpa

******************************************************************************************************************************************************************************
* Sample screens

* drop states 
drop if statename == "Ohio" | statename == "Virginia"

* balance
bysort state_naics_size_id: egen totalobs = count(logpay)
qui sum totalobs
keep if totalobs == `r(max)'

******************************************************************************************************************************************************************************
* Calc weights

capture drop empltotal 
capture drop estbshare
bysort naics_size_year_id: egen empltotal = total(empl)
gen emplshare = empl / empltotal
bysort naics_size_year_id: egen estbtotal3 = total(estb)
gen estbshare = estb / estbtotal


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Restriction on double-matched state-years

* restrict to sample with full coverage to estimate quadruple diff
qui reghdfe logpay L1_CPAMob_small_cpa [aw = emplshare], a(state_naics_size_id state_naics_year_id state_size_year_id naics_size_year_id) cluster(state_id)
gen incl1 = (e(sample) == 1)
qui reghdfe logempl L1_CPAMob_small_cpa, a(state_naics_size_id state_naics_year_id state_size_year_id naics_size_year_id) cluster(state_id)
gen incl2 = (e(sample) == 1)
qui reghdfe logemp2estb L1_CPAMob_small_cpa [aw = estbshare], a(state_naics_size_id state_naics_year_id state_size_year_id naics_size_year_id) cluster(state_id)
gen incl3 = (e(sample) == 1)
qui reghdfe logestb L1_CPAMob_small_cpa, a(state_naics_size_id state_naics_year_id state_size_year_id naics_size_year_id) cluster(state_id)
gen incl4 = (e(sample) == 1)
keep if incl1 == 1 & incl2 == 1 & incl3 == 1 & incl4 == 1

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Table 3, Panel C: Quadruple diff spec 

eststo clear
eststo: reghdfe logpay L1_CPAMob_small_cpa [aw = emplshare], a(state_naics_size_id state_naics_year_id state_size_year_id naics_size_year_id) cluster(state_id)
eststo: reghdfe logempl L1_CPAMob_small_cpa, a(state_naics_size_id state_naics_year_id state_size_year_id naics_size_year_id) cluster(state_id)
eststo: reghdfe logemp2estb L1_CPAMob_small_cpa [aw = estbshare], a(state_naics_size_id state_naics_year_id state_size_year_id naics_size_year_id) cluster(state_id)
eststo: reghdfe logestb L1_CPAMob_small_cpa, a(state_naics_size_id state_naics_year_id state_size_year_id naics_size_year_id) cluster(state_id)
esttab using "./Output/Table3_PanelC.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Table 3, Panel A: CPA only estimates

* keep only CPAs and re-prep weights
keep if cpa == 1

capture drop emplshare 
capture drop emptotal 
capture drop estbtotal 
capture drop estbshare
bysort entrsize year: egen emptotal = total(empl)
gen empshare = empl / emptotal
bysort entrsize year: egen estbtotal = total(estb)
gen estbshare = estb / estbtotal

* merge in state-year controls -- before: state-year FE, controls absorbed
capture drop _merge 
merge m:1 area_fips year using "./Data/Controls/extendedstatecontrols.dta"
assert _merge != 1
drop if _merge == 2 /*years available in QCEW but not in SUSB (starting in 2007)*/
drop _merge 

* Table 3, Panel A: CPA small vs Large
eststo clear
eststo: reghdfe logpay L1_CPAMob_small if cpa == 1 [aw = empshare], a(state_size_id size_year_id state_year_id) cluster(state_id)
eststo: reghdfe logempl L1_CPAMob_small if cpa == 1 , a(state_size_id size_year_id state_year_id) cluster(state_id)
eststo: reghdfe logemp2estb L1_CPAMob_small [aw = estbshare] if cpa == 1 , a(state_size_id size_year_id state_year_id) cluster(state_id)
eststo: reghdfe logestb L1_CPAMob_small if cpa == 1 , a(state_size_id size_year_id state_year_id) cluster(state_id)
esttab using "./Output/Table3_PanelA.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Graphical Analysis -- note: SUSB program starts in 2007 --> fewer pre-period data points

******************************************************************************************************************************************************************************
* Event time dummies 

gen eventtime = year - adoption_year
gen lead1small = (eventtime == -1 & smallfirm == 1)
label var lead1small "t=-1"
gen leadlarger2small = (eventtime <= -2 & smallfirm == 1)
label var leadlarger2small "t≤-2"
gen lag0small = (eventtime == 0 & smallfirm == 1)
label var lag0small "t=0"
gen lag1small = (eventtime == 1 & smallfirm == 1)
label var lag1small "t=1"
gen lag2small = (eventtime == 2 & smallfirm == 1)
label var lag2small "t=2"
gen lag3small = (eventtime == 3 & smallfirm == 1)
label var lag3small "t=3"
gen laglarger4small = (eventtime >= 4 & smallfirm == 1)
labe var laglarger4small "t≥4"

******************************************************************************************************************************************************************************
* Figure 1, Panel B: Event time plot SUSB-state CPA large vs small 

capture gen zero = 0
label var zero "t=-1"
reghdfe logpay leadlarger2small zero /* lead1small */ lag0small lag1small lag2small lag3small laglarger4small if cpa == 1 [aw = empshare], ///
	a(state_year_id state_size_id size_year_id) cluster(state_id)
coefplot, keep(*small zero) vert omit ///
	yscale(r(-0.1 0.1)) ylabel(-0.1(.05)0.1) ci(95) ciopt(recast(rcap) lcolor(gs0)) mcolor(gs0) lcolor(gs0) mcolor(gs0) xline(2.5, lpattern(dash) lcolor(gs0)) graphregion(color(white)) 
graph export "./Output/Figure1_PanelB.pdf", as(pdf) replace
graph close 

