******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* QCEW border-county-level prep and analyses

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Import and clean data

******************************************************************************************************************************************************************************
* Import raw QCEW data

filelist, dir("./Data/Census/Data_QCEW/QCEW_RAWData/") pat("*.csv") save("./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta") replace
use "./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta", clear 
local obs = _N
forvalues i=1/`obs' {
	use "./Data/Census/Data_QCEW/QCEW_RAWData/csv_qcew_cpas_datasets.dta" in `i', clear
	local d = dirname + "/" + filename
	local f = filename /*needed for getting the years*/ 
	import delimited using "`d'", stringcols(_all) clear 
	gen filename = "`f'"
	keep if agglvl_code == "78" /*keep only 6 digits naics county-level variables*/
	keep if own_code == "5" /*keep only privately owned*/
	keep if industry_code == "541211" /*keep only CPAs*/
	foreach var of varlist *disclosure_code {
		gen `var'_str = "null" 
		if missing(`var') {
			replace `var'_str = "blank"
		}
		else {
			replace `var'_str = "N"
		}
		drop `var'
	}
	tempfile save`i'
	save "`save`i''"
}

use "`save1'", clear
forvalues i=2/`obs' {
	append using "`save`i''"
}

* var format 
ds area_fips industry_code qtr filename disclosure_code_str lq_disclosure_code_str oty_disclosure_code_str, not
foreach v of var `r(varlist)' {
	destring `v', replace 
}


******************************************************************************************************************************************************************************		 
* Align sample period

* align sample period with state-level QCEW analyses
tab year
keep if year >= 2003

******************************************************************************************************************************************************************************		 
* Merge in treatments and sample screen

******************************************************************************************************************************************************************************
* Merge prep and merge with law dummies

* (temp) recode the state indetifiers for the merges
gen area_fips_merge_temp = substr(area_fips,1,2) + "000" /*only need the first two--treatment assignment at the state level*/
rename area_fips area_fips_original /*renaming required for merge*/
rename area_fips_merge_temp area_fips
merge m:1 area_fips year using "./Data/Helper/LawDummiesCensusCounty.dta"
rename area_fips area_fips_merge_temp /*reverse renaming*/
rename area_fips_original area_fips  

* tab year if _merge == 1 /*not matched from master*/
drop if year <= 2002 /*consistency with State-level and Dummy file*/

* impose sample restriction
drop if area_fips_merge_temp == "15000" /*Hawaii*/
drop if area_fips_merge_temp == "72000" /*Puerto Rico*/
drop if area_fips_merge_temp == "78000" /*Virgin Island*/ 

* adjust treatment dummies to be equal to 1 for later years, when all sample states adopted
replace L1_CPAMobility_Effec_longpanel = 1 if year >= 2015 
drop _merge 


******************************************************************************************************************************************************************************		 
* Balancing check

egen county_id = group(area_fips)
xtset county_id year, yearly

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Merge in identifiers and control variables

******************************************************************************************************************************************************************************
* Merge with the adjanct county file

capture drop _merge
merge m:1 area_fips using "./Data/Helper/CPAMobility_AdjanctCountiesBorderIDs.dta"
tab statepair if _merge == 2
tab homestate if _merge == 2
drop if _merge == 2
gen neighbor_county = 0
replace neighbor_county = 1 if _merge == 3
drop _merge

******************************************************************************************************************************************************************************
* Merge in mapping info

capture drop _merge
merge m:1 area_fips using "./Data/Helper/us_county_db.dta" 
tab NAME if _merge == 2 
drop if _merge == 2 
drop _merge

******************************************************************************************************************************************************************************
* Merge state-level controls 

rename area_fips area_fips_original /*renaming needed for merge -- macro controls except for unemp (merged in below) are only available at the state level*/
rename area_fips_merge_temp area_fips
capture drop _merge
merge m:1 area_fips year using "./Data/Controls/extendedstatecontrols.dta"
rename area_fips area_fips_merge_temp /*reverse renaming*/ 
rename area_fips_original area_fips 
drop if _merge != 3

******************************************************************************************************************************************************************************
* Merge county-level controls 

preserve
use "./Data/Controls/CPAMobility_BLS_LAUS_CountyEmployment.dta", clear
keep area_fips area_title_LAUS year unemploymentrate
replace year = year + 1 /*gen lagged structure*/
rename unemploymentrate L1_unemploymentrate
* Rename county level control for consistency and clarity
rename L1_unemploymentrate L1_unemp_county 
tempfile unempcounty
save `unempcounty'
restore

capture drop _merge
merge 1:1 area_fips year using `unempcounty'
keep if _merge ==3

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Analysis and variable preparation

******************************************************************************************************************************************************************************
* Prep response vars

* Prep pay 
gen pay = avg_annual_pay
gen logpay = log(avg_annual_pay)

* Prep emp
rename annual_avg_emplvl emp
gen logemp = log(emp)


******************************************************************************************************************************************************************************
* Prep FEs 

qui capture drop border_id
capture egen border_id = group(BORDINDX)
capture egen county_id = group(area_fips)
capture egen state_id = group(area_fips_merge_temp)

******************************************************************************************************************************************************************************
* Introduce non-overlaping treatdate condition

capture drop adoption_year
gen adoption_year = .
bysort area_fips year: replace adoption_year = year if CPAMobility_Effec == 1


levelsof statefip, local(states)
foreach s of local states {
	sum adoption_year if statefip == `s'
	replace adoption_year = r(max) if statefip == `s' & missing(adoption_year)
}

capture drop diff_adoption 
gen diff_adoption = 0
levelsof border_id, local(levels)
foreach l of local levels {
	sum adoption_year if border_id == `l'
	replace diff_adoption = 1 if r(sd) != 0 & border_id == `l'

}

******************************************************************************************************************************************************************************
* Figure 2: Border counties with non-overlapping treatment dates 

spmap neighbor_county using us_county_coord if year == 2005 & stateicp != 81, id(id) fcolor(Blues) clmethod(unique)
graph export "./Output/Figure2.pdf", as(pdf) replace

******************************************************************************************************************************************************************************
* Keep only diff-adoption counties 

keep if diff_adoption == 1

******************************************************************************************************************************************************************************
* Further est sample conditions to ascertain estimation on consistently disclosing--that is, no Census confidentiality--counties

* gen counter for balancing
sort area_fips year
bysort area_fips: gen counter = _N

* condition: only disclosing counties--that is, counties displaying above-zero employees throughout
capture drop minemp
bysort county_id: egen minemp = min(emp)

******************************************************************************************************************************************************************************
* Calc weights

capture drop empshare emptotal
bysort year: egen emptotal = total(emp)
gen empshare = emp / emptotal

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Regression analysis 

preserve 

* impose restriction
keep if counter == 15 & neighbor_county == 1 & border_id != 74 & diff_adoption == 1 & !missing(logpay) & minemp > 0 /*BorderID 74 is Lake Michigan*/

* impose reg restriction to ascertain same obs across specifications
qui reghdfe logpay L1_CPAMobility_Effec_longpanel [aw = empshare], a(county_id i.border_id#i.year) cluster(state_id)
keep if (e(sample)) == 1

* Table 4, Panel B: Border-county analysis
eststo clear
eststo: reghdfe logpay L1_CPAMobility_Effec_longpanel [aw = empshare], a(county_id i.border_id#i.year) cluster(state_id)
eststo: reghdfe logpay L1_CPAMobility_Effec_longpanel L1_unemp_county L1_gdp [aw = empshare], a(county_id i.border_id#i.year) cluster(state_id)
eststo: reghdfe logpay L1_CPAMobility_Effec_longpanel L1_betweenstatemigration L1_abroadmigration [aw = empshare], a(county_id i.border_id#i.year) cluster(state_id)
eststo: reghdfe logpay L1_CPAMobility_Effec_longpanel L1_unemp_county L1_gdp L1_betweenstatemigration L1_abroadmigration [aw = empshare], a(county_id i.border_id#i.year) cluster(state_id)

eststo: reghdfe logemp L1_CPAMobility_Effec_longpanel, a(county_id i.border_id#i.year) cluster(state_id)
eststo: reghdfe logemp L1_CPAMobility_Effec_longpanel L1_unemp_county L1_gdp, a(county_id i.border_id#i.year) cluster(state_id)
eststo: reghdfe logemp L1_CPAMobility_Effec_longpanel L1_betweenstatemigration L1_abroadmigration, a(county_id i.border_id#i.year) cluster(state_id)
eststo: reghdfe logemp L1_CPAMobility_Effec_longpanel L1_unemp_county L1_gdp L1_betweenstatemigration L1_abroadmigration, a(county_id i.border_id#i.year) cluster(state_id)
esttab using "./Output/Table4_PanelB.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

* Table 4, Panel A: Desc stats 
tabstat pay logpay emp logemp L1_unemp_county L1_gdp L1_betweenstatemigration L1_abroadmigration, ///
	s(n mean sd p1 p25 p50 p75 p99) columns(statistics) 

restore 
