******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* AICPA MAP Survey prep and analyses

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Raw data import, prep, and checks

filelist, dir("./Data/AICPA/Data_MapSurvey/CPAMobility_Staffing/CPAMobility_Staffing_StataImport/") pat("*.xlsx") save("./Data/AICPA/Data_MapSurvey/CPAMobility_Staffing/CPAMobility_Staffing_StataImport/MAPSurvey_Staffing_datasets.dta") replace

use "./Data/AICPA/Data_MapSurvey/CPAMobility_Staffing/CPAMobility_Staffing_StataImport/MAPSurvey_Staffing_datasets.dta", clear /*23 obs - correct*/
local obs = _N
forvalues i=1/`obs' {
	use "./Data/AICPA/Data_MapSurvey/CPAMobility_Staffing/CPAMobility_Staffing_StataImport/MAPSurvey_Staffing_datasets.dta" in `i', clear
	local f = dirname + "/" + filename
	local g = filename
	import excel "`f'", sheet("Sheet1") allstring clear
	drop if missing(A) /*drop empty columns in collection sheet*/
	drop B /*drop notes column */

	sxpose, clear /*ssc install, if required*/
	renvars , map(`=word("@", 1)') /*take the first row as variable name*/
	drop if _n == 1 /*drop empty row -- collection notes*/
	rename Variable size_class
	capture replace size_class = "single_medium_2002" if size_class == "single_medium_2004" /*correcting a labeling issues in raw files*/
	drop if missing(size_class) /*drop empty cells*/

	ds size_class, not
	foreach var in `r(varlist)' {
		gen r_`var' = real(`var')
		drop `var' 
		rename r_`var' `var'  
	}	
	gen year = substr(size_class, length(size_class) - 3, 4)
	gen size_class_temp = substr(size_class, 1, length(size_class) - 5)
	drop size_class
	rename size_class_temp size_class
	gen source = "`f'"
	gen source_file = "`g'"
	tempfile save`i'
	save "`save`i''"
}

* append all files
use "`save1'", clear
	forvalues i=2/`obs' {
    append using "`save`i''"
}
/*71 vars = 69 vars + source var + filename var --> correct*/
/*805 obs = 35 obs per state * 23 states = 805 -- > correct*/


* Introduce area fips for merging in dummy structure
replace source_file = subinstr(source_file, "StataImport_Staffing_", "", .)
replace source_file = subinstr(source_file, ".xlsx", "", .)
gen area_fips = "."
replace area_fips = "04000" if source_file == "Arizona"
replace area_fips = "06000" if source_file == "California"
replace area_fips = "08000" if source_file == "Colorado"
replace area_fips = "12000" if source_file == "Florida"
replace area_fips = "13000" if source_file == "Georgia"
replace area_fips = "17000" if source_file == "Illinois"
replace area_fips = "18000" if source_file == "Indiana"
replace area_fips = "22000" if source_file == "Louisiana"
replace area_fips = "24000" if source_file == "Maryland"
replace area_fips = "25000" if source_file == "Massachusetts"
replace area_fips = "26000" if source_file == "Michigan"
replace area_fips = "27000" if source_file == "Minnesota"
replace area_fips = "34000" if source_file == "NewJersey"
replace area_fips = "36000" if source_file == "NewYork"
replace area_fips = "37000" if source_file == "NorthCarolina"
replace area_fips = "39000" if source_file == "Ohio"
replace area_fips = "40000" if source_file == "Oklahoma"
replace area_fips = "41000" if source_file == "Oregon"
replace area_fips = "42000" if source_file == "Pennsylvania"
replace area_fips = "48000" if source_file == "Texas"
replace area_fips = "51000" if source_file == "Virginia"
replace area_fips = "53000" if source_file == "Washington"
replace area_fips = "55000" if source_file == "Wisconsin"

* year variable
capture drop r_year
gen r_year = real(year) 
drop year
rename r_year year

* save temp set
preserve


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Preparation of law dummy file (adjust to accommodate biennial structure of the MAP survey) and sample screen

* merge in adjusted dummy structure
import excel "./Data/Helper/CPAMobility_MAPSurvey_Adoption.xlsx", sheet("Mobility_Effective") firstrow clear
reshape long v_, i(effective_sequence stateicp_string stateicp stateicp_valuelabel ST STATE statefip area_fips Effective_Date) j(year)

* gen long panel variable
sort ST year

gen CPAMobility_Effec_longpanel = 0
replace CPAMobility_Effec_longpanel = 1 if v_ == 1 
sort ST year
by ST: replace CPAMobility_Effec_longpanel = 1 if  CPAMobility_Effec_longpanel[_n-1] == 1
 
* generate merge variable
gen area_fips_temp = string(area_fips)
drop area_fips
rename area_fips_temp area_fips
replace area_fips = "0" + area_fips if length(area_fips) == 4

* save dummy file
tempfile dummies
save `dummies'

* use master and merge in law dummies
restore
merge m:1 area_fips year using `dummies' /*all matched from master*/
tab STATE if _merge == 2
codebook STATE if _merge == 2 /*27 states --> correct */
keep if _merge == 3
drop _merge

* drops
drop if source_file == "Ohio"
drop if source_file == "Virginia"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Prep and aux regressions 

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Compensation prep

* Missing Check
foreach var of varlist comp_partner comp_director comp_sr_manager comp_manager comp_sr_associate comp_associate comp_newprof {
  replace `var' = .  if `var' == 0
  gen log`var' = log(`var')
}
egen comp_all = rmean(comp_partner comp_director comp_sr_manager comp_manager comp_sr_associate comp_associate)
gen logcomp_all = log(comp_all)
egen comp_senior = rmean(comp_partner )
gen logcomp_senior = log(comp_senior)
egen comp_mid = rmean(comp_director comp_sr_manager comp_manager)
gen logcomp_mid = log(comp_mid)
egen comp_low = rmean(comp_sr_associate comp_associate)
gen logcomp_low = log(comp_low)

gen non_miss = 0 
replace non_miss = 1 if !missing(comp_senior) & !missing(comp_mid) & !missing(comp_low)

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Billing rate prep

foreach var of varlist avgbill_partner avgbill_director avgbill_sr_manager avgbill_manager avgbill_sr_associate avgbill_associate avgbill_newprof {
  replace `var' = .  if `var' == 0
  gen log`var' = log(`var')
}

* generate position partitions
egen avgbill_all = rmean( avgbill_partner avgbill_director avgbill_sr_manager avgbill_manager avgbill_sr_associate avgbill_associate)
gen logavgbill_all = log(avgbill_all)
egen avgbill_senior = rmean( avgbill_partner )
gen logavgbill_senior = log(avgbill_senior)
egen avgbill_mid = rmean( avgbill_director avgbill_sr_manager avgbill_manager)
gen logavgbill_mid = log(avgbill_mid)
egen avgbill_low = rmean( avgbill_sr_associate avgbill_associate)
gen logavgbill_low = log(avgbill_low)

gen non_miss_bill = 0 
replace non_miss_bill = 1 if !missing(avgbill_senior) & !missing(avgbill_mid) & !missing(avgbill_low)

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Hours billed prep

foreach var of varlist avgcharg_partner avgcharg_director avgcharg_sr_manager avgcharg_manager avgcharg_sr_associate avgcharg_associate avgcharg_newprof {
  replace `var' = .  if `var' == 0
  gen log`var' = log(`var')
}

* generate different position partitions
egen avgcharg_all = rmean( avgcharg_partner avgcharg_director avgcharg_sr_manager avgcharg_manager avgcharg_sr_associate avgcharg_associate)
gen logavgcharg_all = log(avgcharg_all)
egen avgcharg_senior = rmean( avgcharg_partner)
gen logavgcharg_senior = log(avgcharg_senior)
egen avgcharg_mid = rmean( avgcharg_director avgcharg_sr_manager avgcharg_manager)
gen logavgcharg_mid = log(avgcharg_mid)
egen avgcharg_low = rmean( avgcharg_sr_associate avgcharg_associate)
gen logavgcharg_low = log(avgcharg_low)

gen non_miss_charge = 0 
replace non_miss_charge = 1 if !missing(avgcharg_senior) & !missing(avgcharg_mid) & !missing(avgcharg_low)

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Regression analysis

* condition to ascertain constant estimation sample across specs
capture drop triple_condition
gen triple_condition = 0
replace triple_condition = 1 if non_miss == 1 & non_miss_bill == 1 & non_miss_charge == 1 

* gen FE
egen state_id = group(area_fips)

* Table 6, Panel B: Baseline
eststo clear		
foreach var of varlist logcomp_all avgbill_all logavgcharg_all {
	qui eststo: reghdfe `var' i.CPAMobility_Effec_longpanel if triple_condition == 1 & year <= 2014 & size_class =="all" [aw = number_firms], a(state_id year) cluster(state_id)	
}	
esttab using "./Output/Table6_PanelB.csv", replace b(3) se(3) ar2 star(* 0.10 ** 0.05 *** 0.01)

* Table 6, Panel C: Logratio test comp
gen logseniorlow = logcomp_senior - logcomp_low
gen logseniormid = logcomp_senior - logcomp_mid
gen logmidlow = logcomp_mid - logcomp_low

eststo clear
foreach var of varlist logseniorlow logseniormid logmidlow {	
	qui eststo: reghdfe `var' i.CPAMobility_Effec_longpanel if triple_condition == 1 & year <= 2015 & size_class =="all" [aw = number_firms], a(state_id year) cluster(state_id)
}
esttab using "./Output/Table6_PanelC.csv", replace b(3) se(3) ar2 star(* 0.10 ** 0.05 *** 0.01)

* Table 6, Panel D: Logratio for billing rates
gen logbill_seniorlow = logavgbill_senior - logavgbill_low
gen logbill_seniormid = logavgbill_senior - logavgbill_mid
gen logbill_midlow = logavgbill_mid - logavgbill_low


eststo clear
foreach var of varlist logbill_seniorlow logbill_seniormid logbill_midlow {	
	qui eststo: reghdfe `var' i.CPAMobility_Effec_longpanel if triple_condition == 1 & year <= 2015 & size_class =="all" [aw = number_firms], a(state_id year) cluster(state_id)
}
esttab using "./Output/Table6_PanelD.csv", replace b(3) se(3) ar2 star(* 0.10 ** 0.05 *** 0.01)

* Table 6, Panel E: Logratios for hours 
gen loghour_seniorlow = logavgcharg_senior - logavgcharg_low
gen loghour_seniormid = logavgcharg_senior - logavgcharg_mid
gen loghour_midlow = logavgcharg_mid - logavgcharg_low

eststo clear
foreach var of varlist loghour_seniorlow loghour_seniormid loghour_midlow {
	qui eststo: reghdfe `var' i.CPAMobility_Effec_longpanel if triple_condition == 1 & year <= 2015 & size_class =="all" [aw = number_firms], a(state_id year) cluster(state_id)
}
esttab using "./Output/Table6_PanelE.csv", replace b(3) se(3) ar2 star(* 0.10 ** 0.05 *** 0.01)

* Table 6, Panel A: Descriptive stats 

* compensation
tabstat comp_all logcomp_all comp_senior comp_mid comp_low if triple_condition == 1 & year <= 2015 & size_class =="all", s(n mean sd p1 p25 p50 p75 p99) columns(statistics)

* billing rates
tabstat avgbill_all avgbill_senior avgbill_mid avgbill_low if triple_condition == 1 & year <= 2015 & size_class =="all", s(n mean sd p1 p25 p50 p75 p99) columns(statistics)

* hours charged 
tabstat avgcharg_all logavgcharg_all avgcharg_senior avgcharg_mid avgcharg_low if triple_condition == 1 & year <= 2015 & size_class =="all", s(n mean sd p1 p25 p50 p75 p99) columns(statistics)
