******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Pension plan prep and analysis 

* File Structure:
* Require three IRS forms: Form 5500 for the plan information, Schedule H for the auditor EIN, and Schedule C for audit fees.
* File imports are split into a 2003-2008 part and 2009-2015 part. Import is split to accommodate file format differences. 

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Imports and merges

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* 2003 to 2008 files


******************************************************************************************************************************************************************************
* Extract auditor and financial info from Schedule H 
 
forvalues i=2003/2008 {
	import delimited "./Data/PensionPlans/Data_Form5500_AuditFees/RawData_Unzipped/F_SCH_H_`i'.csv",  encoding(ISO-8859-1) clear 
	keep filing_id accountant_firm_name accountant_firm_ein acct_performed_ltd_audit_ind acct_opin_not_on_file_ind acctnt_opinion_type_ind /*controls:*/ joint_venture_boy_amt real_estate_boy_amt tot_assets_boy_amt tot_liabilities_boy_amt tot_contrib_amt professional_fees_amt contract_admin_fees_amt invst_mgmt_fees_amt other_admin_fees_amt tot_admin_expenses_amt aggregate_proceeds_amt net_income_amt
	drop if missing(accountant_firm_ein) 
	tostring accountant_firm_ein, replace /*convert to string for consistency across files and years*/
	tostring net_income_amt, replace force 
	gen year = `i'
	tempfile temp`i'
	save `temp`i''
}
use `temp2003', clear
forvalues i = 2004/2008{
	append using `temp`i''
}
save "./Data/PensionPlans/Data_Form5500_AuditFees/schedule_h_0308.dta", replace 

******************************************************************************************************************************************************************************
* Extract fees from Schedule C Part 1

forvalues i=2003/2008 {
	import delimited "./Data/PensionPlans/Data_Form5500_AuditFees/RawData_Unzipped/F_SCH_C_PART1_`i'.csv", encoding(ISO-8859-1) clear 
	drop if missing(provider_01_ein)
	tostring provider_01_ein, replace
	tostring provider_01_srvc_code, replace
	gen year = `i'
	tempfile temp2`i'
	save `temp2`i''
}
use `temp22003', clear
forvalues i = 2004/2008{
	append using `temp2`i''
}
save "./Data/PensionPlans/Data_Form5500_AuditFees/schedule_c_0308.dta", replace 


******************************************************************************************************************************************************************************
* Merge Schedule H and Schedule C

use "./Data/PensionPlans/Data_Form5500_AuditFees/schedule_h_0308.dta", clear
gen provider_01_ein = accountant_firm_ein /*adjust for merge*/
duplicates tag filing_id provider_01_ein year, gen(dupl)
duplicates drop filing_id provider_01_ein year, force /*5 true duplicates*/
merge 1:m filing_id provider_01_ein year using "./Data/PensionPlans/Data_Form5500_AuditFees/schedule_c_0308.dta"
keep if _merge == 3
drop _merge 

* keep only main service provider role
capture drop dupl
duplicates tag filing_id year, gen(dupl)
tab dupl
sort filing_id year
* browse if dupl > 0 /*Only keep the main service--that is, audit not preparation*/
capture drop dupl
duplicates tag filing_id year row_num, gen(dupl) 
tab dupl 
sort filing_id year row_num 
by filing_id year: gen counter = _n 
keep if counter == 1 /*keep main role*/
drop counter 

* save merged file for handling
save "./Data/PensionPlans/Data_Form5500_AuditFees/planauditors_0308.dta", replace 


******************************************************************************************************************************************************************************
* Extract location and other plan info from Form 5500

forvalues i=2003/2008 {
	import delimited "./Data/PensionPlans/Data_Form5500_AuditFees/RawData_Unzipped/f_5500_`i'.csv", encoding(ISO-8859-1) clear
	* keep location and info for controls
	keep filing_id spons_dfe_ein spons_dfe_pn plan_name sponsor_dfe_name spons_dfe_city spons_dfe_state admin_name admin_ein admin_city admin_state preparer_name preparer_ein preparer_city preparer_state tot_partcp_boy_cnt collective_bargain_ind type_plan_entity_ind type_dfe_plan_entity partcp_account_bal_cnt
	* Convert the variables to strings except for filing id for merges and consistency
	foreach var of varlist spons_dfe_ein spons_dfe_pn plan_name sponsor_dfe_name spons_dfe_city spons_dfe_state admin_name admin_ein admin_city admin_state preparer_name preparer_ein preparer_city preparer_state tot_partcp_boy_cnt collective_bargain_ind type_plan_entity_ind type_dfe_plan_entity partcp_account_bal_cnt {
		capture tostring `var', replace 
	}

	gen year = `i'
	tempfile temp3`i'
	save `temp3`i''
}

use `temp32003', clear
forvalues i = 2004/2008{
	append using `temp3`i''
}

* save file for handling
save "./Data/PensionPlans/Data_Form5500_AuditFees/form5500_0308.dta", replace 

******************************************************************************************************************************************************************************
* Merge Form 5500 with merged auditor and fee File (Schedules H and C, merged above)

use "./Data/PensionPlans/Data_Form5500_AuditFees/form5500_0308.dta", clear 
merge m:1 filing_id year using "./Data/PensionPlans/Data_Form5500_AuditFees/planauditors_0308.dta"
keep if _merge == 3 
drop _merge

* drop vars no longer needed and save merged file for handling
capture drop dupl image_form_id	page_id	page_row_num page_seq row_num
save "./Data/PensionPlans/Data_Form5500_AuditFees/pensionplanaudits_0308.dta", replace


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* 2009 to 2015 files

******************************************************************************************************************************************************************************
* Extract Auditor and financial info from Schedule H

forvalues i = 2009/2015 {
	import delimited "./Data/PensionPlans/Data_Form5500_AuditFees/RawData_Unzipped/F_SCH_H_`i'_latest.csv", encoding(ISO-8859-1) clear
	keep ack_id accountant_firm_name accountant_firm_ein acct_performed_ltd_audit_ind acct_opin_not_on_file_ind acctnt_opinion_type_cd /*controls:*/ joint_venture_boy_amt real_estate_boy_amt tot_assets_boy_amt tot_liabilities_boy_amt tot_contrib_amt professional_fees_amt contract_admin_fees_amt invst_mgmt_fees_amt other_admin_fees_amt tot_admin_expenses_amt aggregate_proceeds_amt net_income_amt
	rename acctnt_opinion_type_cd acctnt_opinion_type_ind /*rename the only one that is not consistent other than the identifier*/
	drop if missing(accountant_firm_ein) 
	tostring accountant_firm_ein, replace /*align format*/
    tostring net_income_amt, replace force /*align format*/
	gen year = `i'
	tempfile temp`i'
	save `temp`i''
}

use `temp2009', clear
forvalues i = 2010/2015{
	append using `temp`i''
}
save "./Data/PensionPlans/Data_Form5500_AuditFees/schedule_h_0915.dta", replace 


******************************************************************************************************************************************************************************
* Extract fees from Schedule C Part 1

forvalues i=2009/2015 {
	import delimited "./Data/PensionPlans/Data_Form5500_AuditFees/RawData_Unzipped/F_SCH_C_PART1_ITEM2_`i'_latest.csv", encoding(ISO-8859-1) clear
	* drop the following that cannot be obtained in prior files 
	drop prov_other_foreign_address1 prov_other_foreign_address2 prov_other_foreign_city prov_other_foreign_prov_state prov_other_foreign_cntry prov_other_foreign_postal_cd
	
	* rename the variables to correspond with the 2003-2008 file (imported above)
	rename provider_other_name provider_01_name 
	rename provider_other_ein provider_01_ein
	gen provider_01_position = "" /*does not exist in the 09 and onwards file*/
	rename provider_other_relation provider_01_relation
	rename prov_other_tot_ind_comp_amt provider_01_salary_amt
	rename provider_other_direct_comp_amt provider_01_fees_amt
	gen provider_01_srvc_code = "." /*converted to string in earlier import*/
	drop provider_other_amt_formula_ind
	drop prov_other_elig_ind_comp_ind 
	drop prov_other_indirect_comp_ind

	* convert the service provider ein to string variable for consistency with 2003-2008 file
	* also have to rename the variable to correspond to the id in the merging file 
	tostring provider_01_ein, replace
	tostring provider_01_srvc_code, replace
	
	* gen year and tempfile
	gen year = `i'
	tempfile temp2`i'
	save `temp2`i''
}

use `temp22009', clear
forvalues i = 2010/2015{
	append using `temp2`i''
}
save "./Data/PensionPlans/Data_Form5500_AuditFees/schedule_c_0915.dta", replace 


******************************************************************************************************************************************************************************
* Merge Schedule H and Schedule C

use "./Data/PensionPlans/Data_Form5500_AuditFees/schedule_h_0915.dta", clear
gen provider_01_ein = accountant_firm_ein /*this needs to be the same in the files*/
duplicates tag ack_id provider_01_ein year, gen(dupl)
tab dupl /*no duplicates here*/
drop dupl 
capture duplicates drop ack_id provider_01_ein year, force /* no obs deleted*/

merge 1:m ack_id provider_01_ein year using "./Data/PensionPlans/Data_Form5500_AuditFees/schedule_c_0915.dta" 

* as before, missing are the ones with below threshold or missing auditor ein info, drop
keep if _merge == 3
drop _merge 

* check and inspect duplicates
capture drop dupl
duplicates tag ack_id year, gen(dupl)
tab dupl

* keep main function only (see 2003-2008 import)
* browse if dupl > 0 
sort ack_id year row_order
by ack_id year: gen counter = _n 
keep if counter == 1 
drop counter   

capture drop dupl
duplicates tag ack_id year, gen(dupl)
tab dupl /*de-duplicated*/
drop dupl

* drop row_order for file concistency with 2003-2008 imports
drop row_order 

* save merged file for handling
save "./Data/PensionPlans/Data_Form5500_AuditFees/planauditors_0915.dta", replace 


******************************************************************************************************************************************************************************
* Extract location and other plan info from Form 5500

forvalues i=2009/2015 {
	import delimited "./Data/PensionPlans/Data_Form5500_AuditFees/RawData_Unzipped/f_5500_`i'_latest.csv", encoding(ISO-8859-1) clear
	
	* renaming and format adjustment for consistency with 2003-2008 import
	rename spons_dfe_mail_us_city spons_dfe_city
	rename spons_dfe_mail_us_state spons_dfe_state
	rename admin_us_city admin_city
	rename admin_us_state admin_state
	rename type_plan_entity_cd type_plan_entity_ind 
	rename type_dfe_plan_entity_cd type_dfe_plan_entity

	keep ack_id spons_dfe_ein spons_dfe_pn plan_name sponsor_dfe_name spons_dfe_city spons_dfe_state admin_name admin_ein admin_city admin_state tot_partcp_boy_cnt collective_bargain_ind type_plan_entity_ind type_dfe_plan_entity partcp_account_bal_cnt
	
	foreach var of varlist spons_dfe_ein spons_dfe_pn plan_name sponsor_dfe_name spons_dfe_city spons_dfe_state admin_name admin_ein admin_city admin_state tot_partcp_boy_cnt collective_bargain_ind type_plan_entity_ind type_dfe_plan_entity partcp_account_bal_cnt {
		capture tostring `var', replace 
	}

	gen year = `i'
	tempfile temp3`i'
	save `temp3`i''
}

use `temp32009', clear
forvalues i = 2010/2015{
	append using `temp3`i''
}
save "./Data/PensionPlans/Data_Form5500_AuditFees/form5500_0915.dta", replace 


******************************************************************************************************************************************************************************
* Merge Form 5500 with merged auditor and fee file (Schedules H and C, merged above)

* earlier file 
use "./Data/PensionPlans/Data_Form5500_AuditFees/form5500_0915.dta", clear 
merge m:1 ack_id year using "./Data/PensionPlans/Data_Form5500_AuditFees/planauditors_0915.dta" /*all merged*/
keep if _merge == 3 
capture drop _merge

* save complete 09-15 file 
save "./Data/PensionPlans/Data_Form5500_AuditFees/pensionplanaudits_0915.dta", replace




******************************************************************************************************************************************************************************
* Append 03-08 file with 09-15 file

/*
* manual check on import -- all var names in order and same across file? yes
use "./Data/PensionPlans/Data_Form5500_AuditFees/pensionplanaudits_0308.dta", clear
capture drop dupl image_form_id	page_id	page_row_num page_seq row_num
order _all, alpha
save "./Data/PensionPlans/Data_Form5500_AuditFees/pensionplanaudits_0308.dta", replace 

* same for the later file 
use "./Data/PensionPlans/Data_Form5500_AuditFees/pensionplanaudits_0915.dta", clear
order _all, alpha
*/ 

use "./Data/PensionPlans/Data_Form5500_AuditFees/pensionplanaudits_0308.dta", clear
append using "./Data/PensionPlans/Data_Form5500_AuditFees/pensionplanaudits_0915.dta"


******************************************************************************************************************************************************************************
* Checks on file structure and drop true duplicates

* multiple entries by plan (number):
duplicates drop spons_dfe_ein year spons_dfe_pn, force /*clean dupl based on plan numbers--manual check via DOL: true duplicates!*/

******************************************************************************************************************************************************************************
* Treatments

gen state = spons_dfe_state 
drop if missing(state) /*required for merge*/

capture drop L1_CPAMobility_Effec_longpanel 
capture drop STUSPS
preserve
use "./Data/Helper/LawDummiesPensionPlans.dta", clear
keep L1_CPAMobility_Effec_longpanel year STUSPS
rename STUSPS state /*state is US postal to allow for merges*/
tempfile lawdummies
save `lawdummies'
restore 
merge m:1 state year using `lawdummies'
keep if _merge == 3
drop _merge 


******************************************************************************************************************************************************************************
* Generate response

* the fees are disclosed as one or the other. checked against DOL plan lookup
replace provider_01_salary_amt = 0 if missing(provider_01_salary_amt)
replace provider_01_fees_amt = 0 if missing(provider_01_fees_amt)
gen fees = provider_01_fees_amt + provider_01_salary_amt

winsor2 fees, suffix(_w) cuts(1 99)
gen logfees = log(fees)
winsor2 logfees, suffix(_w) cuts(1 99)

******************************************************************************************************************************************************************************
* Generate controls

* size: assets
gen logassets = log(tot_assets_boy_amt)
winsor2 logassets, suffix(_w) cuts (1 99)

* contribution to assets
gen contribution2assets = tot_contrib_amt / tot_assets_boy_amt
winsor2 contribution2assets, suffix(_w) cuts(1 99)

* participants to assets
destring tot_partcp_boy_cnt, replace /*to-string before for consistency*/
gen participants2assets = tot_partcp_boy_cnt / tot_assets_boy_amt
winsor2 participants2assets, suffix(_w) cuts(1 99)

* hardtoaudit
replace joint_venture_boy_amt = 0 if missing(joint_venture_boy_amt) /*true zeros according to DoL plan lookup*/
replace real_estate_boy_amt = 0 if missing(real_estate_boy_amt) /*true zeros according to DoL plan lookup*/
gen hardtoaudit = (joint_venture_boy_amt + real_estate_boy_amt) / tot_assets_boy_amt
winsor2 hardtoaudit, suffix(_w) cuts(1 99)

* investment mgmt fees
gen investfees2assets = invst_mgmt_fees_amt / tot_assets_boy_amt
winsor2 investfees2assets, suffix(_w) cuts(1 99)

* profitibality
destring net_income_amt, gen(netincome)  
gen income2assets = netincome / tot_assets_boy_amt
winsor2 income2assets, suffix(_w) cuts(1 99)

* limited 
gen limited = (acct_performed_ltd_audit_ind == 1)

* Big 4 (raw)
gen big4 = 0
gen auditor_name = lower(accountant_firm_name)
replace big4 = 1 if strpos(auditor_name, "kpmg")
replace big4 = 1 if strpos(auditor_name, "price")
replace big4 = 1 if strpos(auditor_name, "deloit")
replace big4 = 1 if strpos(auditor_name, "ernst")

* adjust Big4 -- recursive approach: min type 1 / 2 error 
tab auditor_name if strpos(auditor_name, "kpmg") 
tab auditor_name if strpos(auditor_name, "price")
replace big4 = 0 if strpos(auditor_name, "price")
replace big4 = 1 if strpos(auditor_name, "price") & strpos(auditor_name, "waterhouse")
tab auditor_name if strpos(auditor_name, "price") & strpos(auditor_name, "waterhouse")
tab auditor_name if strpos(auditor_name, "deloit") 
tab auditor_name if strpos(auditor_name, "ernst") 
replace big4 = 0 if strpos(auditor_name, "ernst")
replace big4 = 1 if strpos(auditor_name, "ernst") & strpos(auditor_name, "young")
tab auditor_name if strpos(auditor_name, "ernst") & strpos(auditor_name, "young")

* add national audit firms -- based on statista -- top 10 audit firms -- string searches based on recursive process with min type 1 / 2 error (as before)
gen national = 0
replace national = 1 if big4 ==1
replace national = 1 if strpos(auditor_name, "rsm")
replace national = 1 if strpos(auditor_name, "thornton")
replace national = 1 if strpos(auditor_name, "bdo")
replace national = 1 if strpos(auditor_name, "clifton")
replace national = 1 if strpos(auditor_name, "mayer") & strpos(auditor_name, "hoffman")
replace national = 1 if strpos(auditor_name, "crowe")

* non Big 4
gen nonbig4 = (big4 == 0)

******************************************************************************************************************************************************************************
* FEs
capture egen state_id = group(state)
capture egen state_year_id = group(state year)
capture egen state_nonbig4_id = group(state nonbig4)
capture egen state_complex_id = group(state complex)
capture egen sponsor_id = group(spons_dfe_ein)
capture egen plan_id = group(spons_dfe_ein spons_dfe_pn)
capture egen auditfirm_id = group(accountant_firm_ein)

******************************************************************************************************************************************************************************
* Sample restriction and check

gen OHVA = (state == "OH" | state == "VA")

* duplicate check
sort spons_dfe_ein spons_dfe_pn year 
duplicates tag spons_dfe_ein spons_dfe_pn year, gen(dupl) 
assert dupl == 0
drop dupl 

* Impose sample restriction
drop if OHVA == 1 
drop if limited == 0  

* Define controls and easy-to-handle treatment
global controls contribution2assets_w  income2assets_w  hardtoaudit_w  logassets_w investfees2assets_w participants2assets_w
gen CPAMob = L1_CPAMobility_Effec_longpanel

******************************************************************************************************************************************************************************
* gen FEs 

capture gen small = (national == 0)
capture gen big = (national == 1)
capture gen CPAMob_small = small * CPAMob
capture gen CPAMob_big = big * CPAMob
capture egen state_national_id = group(state national)
capture egen national_year_id = group(national year)
capture egen state_national_year_id = group(state national year)
capture egen auditfirm_state_id = group(auditfirm state)

******************************************************************************************************************************************************************************
* Collapse regression to have at least a minimum level of obs per state-firmsize-year cell to estimate the full model

preserve
reghdfe logfees_w ${controls}, a(state_national_year_id auditfirm_state_id, savefe)
gen includedobs = (e(sample) == 1)
rename __hdfe1__ state_national_year_fees
collapse state_national_year_fees CPAMob* national (sum) includedobs, by(state_national_year_id state_national_id state_id state year)

keep if includedobs >= 5 /*minimum level of obs to identify groups*/

bysort state_id: egen stateyears = count(state_national_year_fees)
keep if stateyears == 26 /*time-group balancing*/
keep state_national_year_id stateyears
tempfile national
save `national'
restore
capture drop _merge 
merge m:1 state_national_year_id using `national'
rename _merge nationalbalancedstate


******************************************************************************************************************************************************************************
* Run models one by one to hold estimation sample constant across specifications 

capture drop inclreg*
qui reghdfe logfees_w CPAMob ${controls} if nationalbalancedstate == 3, a(auditfirm_state_id year) cluster(state_id) /*2.3% decline*/
gen inclreg1 = (e(sample) == 1)
qui reghdfe logfees_w CPAMob ${controls} if national == 1 & nationalbalancedstate == 3, a(auditfirm_state_id year) cluster(state_id) 
gen inclreg2 = (e(sample) == 1)
qui reghdfe logfees_w CPAMob ${controls} if national == 0 & nationalbalancedstate == 3, a(auditfirm_state_id year) cluster(state_id) 
gen inclreg3 = (e(sample) == 1)
qui reghdfe logfees_w CPAMob_small CPAMob_big ${controls} if nationalbalancedstate == 3, a(auditfirm_state_id national_year_id) cluster(state_id) 
gen inclreg4 = (e(sample) == 1)
gen inclreg = (inclreg1 == 1 & (inclreg2 == 1 | inclreg3 == 1) & inclreg4 == 1)

******************************************************************************************************************************************************************************
* Estimate model on sample meeting all requirements

preserve 
keep if inclreg == 1

* Table 7, Panel B: Pension plan audit fee response 
eststo clear 
eststo: reghdfe logfees_w CPAMob ${controls} if nationalbalancedstate == 3, a(auditfirm_state_id year) cluster(state_id)
eststo: reghdfe logfees_w CPAMob_small CPAMob_big ${controls} if nationalbalancedstate == 3, a(auditfirm_state_id national_year_id) cluster(state_id) 
test CPAMob_small CPAMob_big
esttab using "./Output/Table7_PanelB.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace

* Table 7, Panel A: Desc stats 
tabstat fees_w logfees_w ${controls} national if nationalbalancedstate == 3, s(n mean sd p1 p25 p50 p75 p99) columns(statistics) 

restore



