******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* AICPA Misconduct prep and analysis 

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Import data received from Armitage and Moriarity (28 June 2017) and prep

* import
import excel "./Data/Quality/AICPA_Notification/Complete Data Set Disciplinary Sanctions_1999-2015.xlsx", sheet("Sheet1") firstrow clear
rename Year year
drop if year < 2003
tab year

* restriction following Armitage and Moriarity
drop if NatureofAct == "F to meet CPE requirement" 
drop if TypeofAct == "F to meet CPE requirement" 
drop if TypeofAct == "Crime" 

* gen temp variable for counting cases
gen case_count = 1

* generate temp variable for counting cases by severity
gen admonished_count = .
replace admonished_count = 1 if case_count == 1 & Outcome == "admonished"
gen suspended_count = 0
replace suspended_count = 1 if case_count == 1 & Outcome == "suspended"
gen terminated_count = 0
replace terminated_count = 1 if case_count == 1 & Outcome == "terminated"

gen total_count = .
replace total_count = 1 if admonished_count == 1
replace total_count = 1 if suspended_count == 1
replace total_count = 1 if terminated_count == 1

* weighted counted to align with EBSA analysis 
gen weighted_count = total_count
replace weighted_count = 1 if admonished_count == 1 
replace weighted_count = 2 if suspended_count == 1
replace weighted_count = 3 if terminated_count == 1 

* collapse case data to state-year panel
collapse (sum) admonished_count (sum) suspended_count (sum) terminated_count (sum) total_count (sum) weighted_count, by(State year) 
rename State ST

* save interim data
tempfile aicpa_misc
save `aicpa_misc'

* merging into a frame to capture true zeros
use "./Data/Helper/LawDummiesAICPAMisconduct.dta", clear
merge 1:1 ST year using `aicpa_misc'

* browse if _merge == 2 /*Note: these are out of sample cases ,e.g., the Al cases from Alberta, Canada*/
drop if _merge ==2

* fill in missing variables -- "true" zeros
foreach var of varlist admonished_count suspended_count terminated_count total_count weighted_count {
	replace `var' = 0 if missing(`var')
}

* drop states not in main analyses for consistency
drop if ST == "HI"
drop if ST == "PR"
drop if ST == "OH"
drop if ST == "VA"
drop if year < 2003

* Prep FEs
egen state_id = group(STATE)
xtset state_id year, yearly


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Regression analysis

* Total count check-reg to ascertain Poisson can be run (min counts)
qui xtpoisson total_count L1_CPAMobility_Effec_longpanel i.year, fe i(state_id) vce(robust) 
gen estsample = (e(sample) == 1) 

* Table 8, Panel A: AICPA Misconduct 

* Total count spec (Poisson and OLS)
eststo clear
qui eststo: reghdfe total_count L1_CPAMobility_Effec_longpanel if estsample == 1, a(year) cluster(state_id)
qui eststo: reghdfe total_count L1_CPAMobility_Effec_longpanel if estsample == 1, a(state_id year) cluster(state_id)
qui eststo: xtpoisson total_count L1_CPAMobility_Effec_longpanel if estsample == 1, fe i(year) vce(robust) /*vce(robust) with specified panel id clusters standard error on the panel id level in xtpoisson (Stata default)*/
qui eststo: xtpoisson total_count L1_CPAMobility_Effec_longpanel i.year if estsample == 1, fe i(state_id) vce(robust) 
qui eststo: reghdfe weighted_count L1_CPAMobility_Effec_longpanel if estsample == 1, a(year) cluster(state_id)
qui eststo: reghdfe weighted_count L1_CPAMobility_Effec_longpanel if estsample == 1, a(state_id year) cluster(state_id)
qui eststo: xtpoisson weighted_count L1_CPAMobility_Effec_longpanel if estsample == 1, fe i(year) 
qui eststo: xtpoisson weighted_count L1_CPAMobility_Effec_longpanel i.year if estsample == 1, fe i(state_id) 
estout, keep(L1_CPAMobility_Effec_longpanel) cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) label
esttab using "./Output/Table8_PanelA.csv", keep(L1_CPAMobility_Effec_longpanel) label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace 

* Re-est Poisson spec for R-Sq output (not displayed in xtpossion, which is needed for standard error clustering) 
eststo clear
qui eststo: poisson total_count L1_CPAMobility_Effec_longpanel i.year if estsample == 1, vce(robust) 
qui eststo: poisson total_count L1_CPAMobility_Effec_longpanel i.year i.state_id if estsample == 1, vce(robust) 
qui eststo: poisson weighted_count L1_CPAMobility_Effec_longpanel i.year if estsample == 1, vce(robust) 
qui eststo: poisson weighted_count L1_CPAMobility_Effec_longpanel i.year i.state_id if estsample == 1, vce(robust) 
estout, keep(L1_CPAMobility_Effec_longpanel) cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) label
esttab using "./Output/Table8_PanelA_R-Squared.csv", keep(L1_CPAMobility_Effec_longpanel) label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) pr2 nodep nonote nomti noli nogap alignment(c) replace 


