******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* EBSA Deficient Filer prep and analysis

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Import and prep 

* Import raw data from DoL
import delimited "./Data/Quality/Data_EBSA_Form5500_Enforcement/ebsa_ocats.csv", encoding(ISO-8859-1)clear

* sample restriction to align with main analyses
drop if plan_admin_state == " "
drop if plan_admin_state == "Ohio"
drop if plan_admin_state == "Virginia"
drop if plan_admin_state == "Hawaii"
drop if plan_admin_state == "Puerto Rico"
rename plan_admin_state state

* prepare year variable
gen year = substr(final_close_date, 1, 4)
destring year, replace 
tab year
drop if year < 2003
drop if year > 2015

* restrict to deficient filers only
keep if case_type == "Deficient Filer"

* generate severity groups as well as a total in line with AICPA Misconduct Analysis
gen sevclass_1 = (penalty_amount == "$0-$10,000")
gen sevclass_2 = (penalty_amount == "$10,001 - $50,000")
gen sevclass_3 = (penalty_amount == "$50,001 - $100,000") 
gen sevclass_4 = (penalty_amount == "over $100,000")

* collapse to casecounts 
preserve
collapse (count) casecount_total=pn, by(state year) /*just count the number of incidents per state and year*/
tempfile ebsa_total
save `ebsa_total'
restore 

* collapse by sev class 
forvalues i=1/4{
	preserve
	keep if sevclass_`i' == 1
	collapse (count) casecount_`i' = pn, by(state year)
	tempfile ebsa_`i'
	save `ebsa_`i''
	restore 
}

* build frame to account for true zeros and generate treatment dummies
import excel "./Data/Helper/DataCollectionFrame.xls", sheet("Sheet1") firstrow clear
rename State state
keep state adoption_year
bysort state: keep if _n == 1 /*start with a cross section of sample states and build frame*/
expand 13
bysort state: gen year = 2002 + _n

* gen the treatment
gen CPAMob = (year - adoption_year >=0)
gen L1_CPAMob = (year - adoption_year > 0) /*here the name is Dist of Columbia - in merge file the state is named*/
replace state = "District of Columbia" if state == "Dist. of Columbia"

* merge with total file 
merge 1:1 state year using `ebsa_total' /*zero from using --> correct*/
replace casecount_total = 0 if _merge == 1 
drop _merge

* merge with the severity files
forvalues i=1/4{
	merge 1:1 state year using `ebsa_`i''
	assert _merge != 2 
	replace casecount_`i' = 0 if _merge == 1
	drop _merge
}

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Outcome prep, control prep, and analysis

******************************************************************************************************************************************************************************
* Prep FEs and set data
egen state_id = group(state)
xtset state_id year, yearly

******************************************************************************************************************************************************************************
* Prep severity weighting aligned with AICPA Misconduct Analysis (Table 8, Panel A)

gen casecount_weighted = casecount_1 * 1 + casecount_2 * 2 + casecount_3 * 3 + casecount_4 * 4

******************************************************************************************************************************************************************************
* Regression analysis

* Table 8, Panel B: EBSA Deficient Filer Cases

eststo clear
qui eststo: reghdfe casecount_total L1_CPAMob, a(year) cluster(state_id)
qui eststo: reghdfe casecount_total L1_CPAMob, a(year state_id) cluster(state_id)
qui eststo: xtpoisson casecount_total L1_CPAMob , fe i(year) vce(robust) /*vce(robust) with specified panel id clusters standard error on the panel id level (Stata default)*/
qui eststo: xtpoisson casecount_total L1_CPAMob i.year, fe i(state_id) vce(robust) 
qui eststo: reghdfe casecount_weighted L1_CPAMob, a(year) cluster(state_id)
qui eststo: reghdfe casecount_weighted L1_CPAMob, a(year state_id) cluster(state_id)
qui eststo: xtpoisson casecount_weighted L1_CPAMob, fe i(year) vce(robust) 
qui eststo: xtpoisson casecount_weighted L1_CPAMob i.year, fe i(state_id) vce(robust)
estout, keep(L1_CPAMob) cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) label
esttab using "./Output/Table8_PanelB.csv", keep(L1_CPAMob) label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace 


* Re-est Poisson spec for R-Sq output (not displayed in xtpossion, which is needed for standard error clustering)
eststo clear 
qui eststo: poisson casecount_total L1_CPAMob i.year, vce(robust) 
qui eststo: poisson casecount_total L1_CPAMob i.year i.state_id, vce(robust) 
qui eststo: poisson casecount_weighted L1_CPAMob i.year, vce(robust) 
qui eststo: poisson casecount_weighted L1_CPAMob i.year i.state_id, vce(robust)
estout, keep(L1_CPAMob) cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** 0.05 *** 0.01) label
esttab using "./Output/Table8_PanelB_R-Squared.csv", keep(L1_CPAMob) label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) pr2 nodep nonote nomti noli nogap alignment(c) replace 
