******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* CO CPA Disciplinary Actions prep and analysis

******************************************************************************************************************************************************************************
* Set directory (only necessary if you are not executing this file from "00_CPAMob_Master.do")

cd "/CPAMobility/"

******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Import and prep

******************************************************************************************************************************************************************************
* Import raw data

import delimited "./Data/Quality/CO_Quality/FRM_-_Public_Accounting_Firm_-_All_Statuses.csv", encoding(ISO-8859-1) stringc(_all) clear /*Downloaded data on 31 August 2019*/

******************************************************************************************************************************************************************************
* Clean Data: Keep only vars needed, entry and exit dates 

* keep variables of interest
keep formattedname state mailzipcode licensetype licensenumber licensefirstissuedate licenselastreneweddate licenseexpirationdate ///
	licensestatusdescription casenumber programaction disciplineeffectivedate disciplinecompletedate /*v29 empty due to csv format*/

* gen entry 
gen firmentryyear = substr(licensefirstissuedate, -4, 4)
destring firmentryyear, replace
drop if missing(firmentryyear) 

* gen exit
gen firmexityear = substr(licenseexpirationdate, -4, 4)
destring firmexityear, replace
drop if missing(firmexityear)

* align licensenumber (all 7 digits)
destring licensenumber, replace 
gen firmlicensenumber = string(licensenumber,"%07.0f")
replace firmlicensenumber = "FRM." + firmlicensenumber 

******************************************************************************************************************************************************************************
* Create tempfile that only holds discplinary actions

preserve

* keep only disciplinary actions
keep if !missing(casenumber)

* gen caseyear
gen caseyear = substr(casenumber, 1, 4)
destring caseyear, replace force
browse if missing(caseyear)
replace caseyear = 2006 if missing(caseyear) /*manually checked these individuals*/

* gen effectiveyear
gen caseeffectiveyear = substr(disciplineeffectivedate, -4,4)
destring caseeffectiveyear, replace /*here all good*/

* check for duplicates in the file
duplicates tag firmlicensenumber caseyear, gen(dupl1)
sort firmlicensenumber caseyear 
browse if dupl1 > 0 /*true duplicates --> remove*/
duplicates drop firmlicensenumber caseyear, force

* keep vars needed for tempfile
keep firmlicensenumber caseyear disciplineeffectivedate casenumber programaction disciplineeffectivedate disciplinecompletedate

* gen year for merging 
gen year = caseyear /*year of the actual violation is what is needed*/

* save tempfile 
tempfile codisc
save `codisc'


******************************************************************************************************************************************************************************
* Reload main file, drop disc action (--> drop duplicates), convert to panel, and merge in disc actions

restore

* drop the disc actions, which are now stored in the tempfile
drop casenumber programaction disciplineeffectivedate disciplinecompletedate 

* drop duplicates (these are coming from disc ations --> taken care of via storing this info in temp file)
duplicates drop firmlicensenumber, force

* convert to panel structure
gen expander = firmexityear - firmentryyear + 1
expand expander
bysort firmlicensenumber: gen sequence = _n - 1
gen year = firmentryyear + sequence

* merge in disc ations and gen outcome
merge 1:1 firmlicensenumber year using `codisc'
drop if _merge == 2
gen discipline = (_merge == 3)
drop _merge

******************************************************************************************************************************************************************************
* Sample restriction, age partition, reg prep

* restriction
keep if year >= 2003 & year <= 2015
keep if firmentryyear <= 2007 /*keep only firms active prior to treatment*/
keep if state == "CO"

* partition on Age
preserve
keep if year == 2007 
egen agequantile = xtile(firmentryyear), n(2)
keep firmlicensenumber agequantile
tempfile age
save `age'
restore
capture drop agequantile
merge m:1 firmlicensenumber using `age'

* gen split variables
gen old = (agequantile == 1)
gen young = (agequantile == 2)

* gen treatment and FEs
capture egen firm_id = group(firmlicensenumber)
capture gen L1_CPAMob_young = (year >= 2009 & young == 1)

* sample inclusion variable
capture gen oldyoung = (old == 1 | young == 1)


******************************************************************************************************************************************************************************
******************************************************************************************************************************************************************************
* Regression analysis

* Table 8, Panel C: CPA Mobility and Discplinary Actions in Colorado
eststo clear
eststo: reghdfe discipline L1_CPAMob_young if oldyoung == 1, a(young year) cluster(firm_id)
eststo: reghdfe discipline L1_CPAMob_young if oldyoung == 1, a(firm_id year) cluster(firm_id)
esttab using "./Output/Table8_PanelC.csv", label b(3) se(3) pa star(* 0.10 ** 0.05 *** 0.01) ar2 nodep nonote nomti noli nogap alignment(c) replace
